# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_logs_get200_response_inner import ApiLogsGet200ResponseInner

class TestApiLogsGet200ResponseInner(unittest.TestCase):
    """ApiLogsGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLogsGet200ResponseInner:
        """Test ApiLogsGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLogsGet200ResponseInner`
        """
        model = ApiLogsGet200ResponseInner()
        if include_optional:
            return ApiLogsGet200ResponseInner(
                id = '0',
                key = '0',
                payload = py_logto.models._api_logs_get_200_response_inner_payload._api_logs_get_200_response_inner_payload(
                    key = '', 
                    result = 'Success', 
                    error = null, 
                    ip = '', 
                    user_agent = '', 
                    user_id = '', 
                    application_id = '', 
                    session_id = '', ),
                created_at = 1.337
            )
        else:
            return ApiLogsGet200ResponseInner(
                id = '0',
                key = '0',
                payload = py_logto.models._api_logs_get_200_response_inner_payload._api_logs_get_200_response_inner_payload(
                    key = '', 
                    result = 'Success', 
                    error = null, 
                    ip = '', 
                    user_agent = '', 
                    user_id = '', 
                    application_id = '', 
                    session_id = '', ),
                created_at = 1.337,
        )
        """

    def testApiLogsGet200ResponseInner(self):
        """Test ApiLogsGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from py_logto.models.api_applications_application_id_roles_get200_response_inner import ApiApplicationsApplicationIdRolesGet200ResponseInner
from py_logto.models.api_applications_application_id_roles_post_request import ApiApplicationsApplicationIdRolesPostRequest
from py_logto.models.api_applications_application_id_roles_put_request import ApiApplicationsApplicationIdRolesPutRequest
from py_logto.models.api_applications_application_id_sign_in_experience_get200_response import ApiApplicationsApplicationIdSignInExperienceGet200Response
from py_logto.models.api_applications_application_id_sign_in_experience_put_request import ApiApplicationsApplicationIdSignInExperiencePutRequest
from py_logto.models.api_applications_application_id_sign_in_experience_put_request_terms_of_use_url import ApiApplicationsApplicationIdSignInExperiencePutRequestTermsOfUseUrl
from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response import ApiApplicationsApplicationIdUserConsentScopesGet200Response
from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response_organization_scopes_inner import ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner
from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response_resource_scopes_inner import ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInner
from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response_resource_scopes_inner_resource import ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInnerResource
from py_logto.models.api_applications_application_id_user_consent_scopes_post_request import ApiApplicationsApplicationIdUserConsentScopesPostRequest
from py_logto.models.api_applications_get200_response_inner import ApiApplicationsGet200ResponseInner
from py_logto.models.api_applications_get200_response_inner_custom_client_metadata import ApiApplicationsGet200ResponseInnerCustomClientMetadata
from py_logto.models.api_applications_get200_response_inner_oidc_client_metadata import ApiApplicationsGet200ResponseInnerOidcClientMetadata
from py_logto.models.api_applications_get200_response_inner_oidc_client_metadata_redirect_uris_inner import ApiApplicationsGet200ResponseInnerOidcClientMetadataRedirectUrisInner
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata import ApiApplicationsGet200ResponseInnerProtectedAppMetadata
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareData
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSsl
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSslValidationErrorsInner
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner import ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerDnsRecordsInner
from py_logto.models.api_applications_get200_response_inner_protected_app_metadata_page_rules_inner import ApiApplicationsGet200ResponseInnerProtectedAppMetadataPageRulesInner
from py_logto.models.api_applications_get_is_third_party_parameter import ApiApplicationsGetIsThirdPartyParameter
from py_logto.models.api_applications_get_types_parameter import ApiApplicationsGetTypesParameter
from py_logto.models.api_applications_id_get200_response import ApiApplicationsIdGet200Response
from py_logto.models.api_applications_id_patch_request import ApiApplicationsIdPatchRequest
from py_logto.models.api_applications_id_patch_request_oidc_client_metadata import ApiApplicationsIdPatchRequestOidcClientMetadata
from py_logto.models.api_applications_id_patch_request_protected_app_metadata import ApiApplicationsIdPatchRequestProtectedAppMetadata
from py_logto.models.api_applications_id_protected_app_metadata_custom_domains_post_request import ApiApplicationsIdProtectedAppMetadataCustomDomainsPostRequest
from py_logto.models.api_applications_id_users_user_id_consent_organizations_get200_response import ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response
from py_logto.models.api_applications_id_users_user_id_consent_organizations_get200_response_organizations_inner import ApiApplicationsIdUsersUserIdConsentOrganizationsGet200ResponseOrganizationsInner
from py_logto.models.api_applications_id_users_user_id_consent_organizations_post_request import ApiApplicationsIdUsersUserIdConsentOrganizationsPostRequest
from py_logto.models.api_applications_id_users_user_id_consent_organizations_put_request import ApiApplicationsIdUsersUserIdConsentOrganizationsPutRequest
from py_logto.models.api_applications_post_request import ApiApplicationsPostRequest
from py_logto.models.api_applications_post_request_protected_app_metadata import ApiApplicationsPostRequestProtectedAppMetadata
from py_logto.models.api_authn_hasura_get200_response import ApiAuthnHasuraGet200Response
from py_logto.models.api_authn_single_sign_on_saml_connector_id_post_request import ApiAuthnSingleSignOnSamlConnectorIdPostRequest
from py_logto.models.api_configs_admin_console_get200_response import ApiConfigsAdminConsoleGet200Response
from py_logto.models.api_configs_admin_console_get200_response_checked_charge_notification import ApiConfigsAdminConsoleGet200ResponseCheckedChargeNotification
from py_logto.models.api_configs_admin_console_get200_response_development_tenant_migration_notification import ApiConfigsAdminConsoleGet200ResponseDevelopmentTenantMigrationNotification
from py_logto.models.api_configs_admin_console_patch_request import ApiConfigsAdminConsolePatchRequest
from py_logto.models.api_configs_jwt_customizer_get200_response_inner import ApiConfigsJwtCustomizerGet200ResponseInner
from py_logto.models.api_configs_jwt_customizer_get200_response_inner_one_of import ApiConfigsJwtCustomizerGet200ResponseInnerOneOf
from py_logto.models.api_configs_jwt_customizer_get200_response_inner_one_of1 import ApiConfigsJwtCustomizerGet200ResponseInnerOneOf1
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response import ApiConfigsJwtCustomizerTokenTypePathGet200Response
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of1 import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of1_token_sample import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1TokenSample
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSample
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_identities_value import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_organization_roles_inner import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserOrganizationRolesInner
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_profile import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_profile_address import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_roles_inner import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInner
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_roles_inner_scopes_inner import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInner
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_roles_inner_scopes_inner_resource import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_sso_identities_inner import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserSsoIdentitiesInner
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_token_sample import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSample
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_token_sample_aud import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSampleAud
from py_logto.models.api_configs_jwt_customizer_token_type_path_put_request import ApiConfigsJwtCustomizerTokenTypePathPutRequest
from py_logto.models.api_configs_oidc_key_type_get200_response_inner import ApiConfigsOidcKeyTypeGet200ResponseInner
from py_logto.models.api_configs_oidc_key_type_rotate_post_request import ApiConfigsOidcKeyTypeRotatePostRequest
from py_logto.models.api_connector_factories_get200_response_inner import ApiConnectorFactoriesGet200ResponseInner
from py_logto.models.api_connectors_connector_id_authorization_uri_post200_response import ApiConnectorsConnectorIdAuthorizationUriPost200Response
from py_logto.models.api_connectors_connector_id_authorization_uri_post_request import ApiConnectorsConnectorIdAuthorizationUriPostRequest
from py_logto.models.api_connectors_factory_id_test_post_request import ApiConnectorsFactoryIdTestPostRequest
from py_logto.models.api_connectors_get200_response_inner import ApiConnectorsGet200ResponseInner
from py_logto.models.api_connectors_get200_response_inner_form_items_inner import ApiConnectorsGet200ResponseInnerFormItemsInner
from py_logto.models.api_connectors_get200_response_inner_form_items_inner_one_of import ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf
from py_logto.models.api_connectors_get200_response_inner_form_items_inner_one_of1 import ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf1
from py_logto.models.api_connectors_get200_response_inner_form_items_inner_one_of_select_items_inner import ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfSelectItemsInner
from py_logto.models.api_connectors_get200_response_inner_form_items_inner_one_of_show_conditions_inner import ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfShowConditionsInner
from py_logto.models.api_connectors_get200_response_inner_metadata import ApiConnectorsGet200ResponseInnerMetadata
from py_logto.models.api_connectors_id_patch_request import ApiConnectorsIdPatchRequest
from py_logto.models.api_connectors_id_patch_request_metadata import ApiConnectorsIdPatchRequestMetadata
from py_logto.models.api_connectors_post_request import ApiConnectorsPostRequest
from py_logto.models.api_connectors_post_request_metadata import ApiConnectorsPostRequestMetadata
from py_logto.models.api_custom_phrases_get200_response_inner import ApiCustomPhrasesGet200ResponseInner
from py_logto.models.api_dashboard_users_active_get200_response import ApiDashboardUsersActiveGet200Response
from py_logto.models.api_dashboard_users_active_get200_response_dau_curve_inner import ApiDashboardUsersActiveGet200ResponseDauCurveInner
from py_logto.models.api_dashboard_users_new_get200_response import ApiDashboardUsersNewGet200Response
from py_logto.models.api_dashboard_users_new_get200_response_today import ApiDashboardUsersNewGet200ResponseToday
from py_logto.models.api_dashboard_users_total_get200_response import ApiDashboardUsersTotalGet200Response
from py_logto.models.api_domains_get200_response_inner import ApiDomainsGet200ResponseInner
from py_logto.models.api_domains_post_request import ApiDomainsPostRequest
from py_logto.models.api_hooks_get200_response_inner import ApiHooksGet200ResponseInner
from py_logto.models.api_hooks_get200_response_inner_config import ApiHooksGet200ResponseInnerConfig
from py_logto.models.api_hooks_get200_response_inner_execution_stats import ApiHooksGet200ResponseInnerExecutionStats
from py_logto.models.api_hooks_id_patch200_response import ApiHooksIdPatch200Response
from py_logto.models.api_hooks_id_patch_request import ApiHooksIdPatchRequest
from py_logto.models.api_hooks_id_test_post_request import ApiHooksIdTestPostRequest
from py_logto.models.api_hooks_id_test_post_request_config import ApiHooksIdTestPostRequestConfig
from py_logto.models.api_hooks_post_request import ApiHooksPostRequest
from py_logto.models.api_hooks_post_request_config import ApiHooksPostRequestConfig
from py_logto.models.api_interaction_bind_mfa_post_request import ApiInteractionBindMfaPostRequest
from py_logto.models.api_interaction_bind_mfa_post_request_one_of import ApiInteractionBindMfaPostRequestOneOf
from py_logto.models.api_interaction_bind_mfa_post_request_one_of1 import ApiInteractionBindMfaPostRequestOneOf1
from py_logto.models.api_interaction_bind_mfa_post_request_one_of1_client_extension_results import ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResults
from py_logto.models.api_interaction_bind_mfa_post_request_one_of1_client_extension_results_crep_props import ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResultsCrepProps
from py_logto.models.api_interaction_bind_mfa_post_request_one_of1_response import ApiInteractionBindMfaPostRequestOneOf1Response
from py_logto.models.api_interaction_bind_mfa_post_request_one_of2 import ApiInteractionBindMfaPostRequestOneOf2
from py_logto.models.api_interaction_consent_get200_response import ApiInteractionConsentGet200Response
from py_logto.models.api_interaction_consent_get200_response_application import ApiInteractionConsentGet200ResponseApplication
from py_logto.models.api_interaction_consent_get200_response_application_branding import ApiInteractionConsentGet200ResponseApplicationBranding
from py_logto.models.api_interaction_consent_get200_response_missing_resource_scopes_inner import ApiInteractionConsentGet200ResponseMissingResourceScopesInner
from py_logto.models.api_interaction_consent_get200_response_missing_resource_scopes_inner_resource import ApiInteractionConsentGet200ResponseMissingResourceScopesInnerResource
from py_logto.models.api_interaction_consent_get200_response_missing_resource_scopes_inner_scopes_inner import ApiInteractionConsentGet200ResponseMissingResourceScopesInnerScopesInner
from py_logto.models.api_interaction_consent_get200_response_organizations_inner import ApiInteractionConsentGet200ResponseOrganizationsInner
from py_logto.models.api_interaction_consent_get200_response_user import ApiInteractionConsentGet200ResponseUser
from py_logto.models.api_interaction_consent_post_request import ApiInteractionConsentPostRequest
from py_logto.models.api_interaction_event_put_request import ApiInteractionEventPutRequest
from py_logto.models.api_interaction_mfa_put_request import ApiInteractionMfaPutRequest
from py_logto.models.api_interaction_mfa_put_request_one_of import ApiInteractionMfaPutRequestOneOf
from py_logto.models.api_interaction_mfa_put_request_one_of1 import ApiInteractionMfaPutRequestOneOf1
from py_logto.models.api_interaction_mfa_put_request_one_of_response import ApiInteractionMfaPutRequestOneOfResponse
from py_logto.models.api_interaction_mfa_skipped_put_request import ApiInteractionMfaSkippedPutRequest
from py_logto.models.api_interaction_put_request import ApiInteractionPutRequest
from py_logto.models.api_interaction_put_request_identifier import ApiInteractionPutRequestIdentifier
from py_logto.models.api_interaction_put_request_identifier_one_of import ApiInteractionPutRequestIdentifierOneOf
from py_logto.models.api_interaction_put_request_identifier_one_of1 import ApiInteractionPutRequestIdentifierOneOf1
from py_logto.models.api_interaction_put_request_identifier_one_of2 import ApiInteractionPutRequestIdentifierOneOf2
from py_logto.models.api_interaction_put_request_identifier_one_of3 import ApiInteractionPutRequestIdentifierOneOf3
from py_logto.models.api_interaction_put_request_identifier_one_of4 import ApiInteractionPutRequestIdentifierOneOf4
from py_logto.models.api_interaction_put_request_identifier_one_of5 import ApiInteractionPutRequestIdentifierOneOf5
from py_logto.models.api_interaction_put_request_identifier_one_of6 import ApiInteractionPutRequestIdentifierOneOf6
from py_logto.models.api_interaction_put_request_identifier_one_of7 import ApiInteractionPutRequestIdentifierOneOf7
from py_logto.models.api_interaction_put_request_profile import ApiInteractionPutRequestProfile
from py_logto.models.api_interaction_single_sign_on_connector_id_authorization_url_post_request import ApiInteractionSingleSignOnConnectorIdAuthorizationUrlPostRequest
from py_logto.models.api_interaction_submit_post200_response import ApiInteractionSubmitPost200Response
from py_logto.models.api_interaction_verification_social_authorization_uri_post_request import ApiInteractionVerificationSocialAuthorizationUriPostRequest
from py_logto.models.api_interaction_verification_totp_post200_response import ApiInteractionVerificationTotpPost200Response
from py_logto.models.api_interaction_verification_verification_code_post_request import ApiInteractionVerificationVerificationCodePostRequest
from py_logto.models.api_interaction_verification_verification_code_post_request_one_of import ApiInteractionVerificationVerificationCodePostRequestOneOf
from py_logto.models.api_interaction_verification_verification_code_post_request_one_of1 import ApiInteractionVerificationVerificationCodePostRequestOneOf1
from py_logto.models.api_interaction_verification_webauthn_authentication_post200_response import ApiInteractionVerificationWebauthnAuthenticationPost200Response
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response import ApiInteractionVerificationWebauthnRegistrationPost200Response
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_authenticator_selection import ApiInteractionVerificationWebauthnRegistrationPost200ResponseAuthenticatorSelection
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_exclude_credentials_inner import ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_extensions import ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_pub_key_cred_params_inner import ApiInteractionVerificationWebauthnRegistrationPost200ResponsePubKeyCredParamsInner
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_rp import ApiInteractionVerificationWebauthnRegistrationPost200ResponseRp
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_user import ApiInteractionVerificationWebauthnRegistrationPost200ResponseUser
from py_logto.models.api_logs_get200_response_inner import ApiLogsGet200ResponseInner
from py_logto.models.api_logs_get200_response_inner_payload import ApiLogsGet200ResponseInnerPayload
from py_logto.models.api_logs_get200_response_inner_payload_error import ApiLogsGet200ResponseInnerPayloadError
from py_logto.models.api_organization_invitations_id_status_put_request import ApiOrganizationInvitationsIdStatusPutRequest
from py_logto.models.api_organization_invitations_post_request import ApiOrganizationInvitationsPostRequest
from py_logto.models.api_organization_roles_get200_response_inner import ApiOrganizationRolesGet200ResponseInner
from py_logto.models.api_organization_roles_id_patch_request import ApiOrganizationRolesIdPatchRequest
from py_logto.models.api_organization_roles_id_resource_scopes_post_request import ApiOrganizationRolesIdResourceScopesPostRequest
from py_logto.models.api_organization_roles_id_resource_scopes_put_request import ApiOrganizationRolesIdResourceScopesPutRequest
from py_logto.models.api_organization_roles_id_scopes_post_request import ApiOrganizationRolesIdScopesPostRequest
from py_logto.models.api_organization_roles_id_scopes_put_request import ApiOrganizationRolesIdScopesPutRequest
from py_logto.models.api_organization_roles_post_request import ApiOrganizationRolesPostRequest
from py_logto.models.api_organization_scopes_id_patch_request import ApiOrganizationScopesIdPatchRequest
from py_logto.models.api_organization_scopes_post_request import ApiOrganizationScopesPostRequest
from py_logto.models.api_organizations_get200_response_inner import ApiOrganizationsGet200ResponseInner
from py_logto.models.api_organizations_id_patch_request import ApiOrganizationsIdPatchRequest
from py_logto.models.api_organizations_id_users_get200_response_inner import ApiOrganizationsIdUsersGet200ResponseInner
from py_logto.models.api_organizations_id_users_post_request import ApiOrganizationsIdUsersPostRequest
from py_logto.models.api_organizations_id_users_put_request import ApiOrganizationsIdUsersPutRequest
from py_logto.models.api_organizations_id_users_roles_post_request import ApiOrganizationsIdUsersRolesPostRequest
from py_logto.models.api_organizations_id_users_user_id_roles_post_request import ApiOrganizationsIdUsersUserIdRolesPostRequest
from py_logto.models.api_organizations_id_users_user_id_roles_put_request import ApiOrganizationsIdUsersUserIdRolesPutRequest
from py_logto.models.api_organizations_post_request import ApiOrganizationsPostRequest
from py_logto.models.api_resources_get200_response_inner import ApiResourcesGet200ResponseInner
from py_logto.models.api_resources_get200_response_inner_scopes_inner import ApiResourcesGet200ResponseInnerScopesInner
from py_logto.models.api_resources_id_is_default_patch_request import ApiResourcesIdIsDefaultPatchRequest
from py_logto.models.api_resources_id_patch_request import ApiResourcesIdPatchRequest
from py_logto.models.api_resources_post_request import ApiResourcesPostRequest
from py_logto.models.api_resources_resource_id_scopes_post_request import ApiResourcesResourceIdScopesPostRequest
from py_logto.models.api_resources_resource_id_scopes_scope_id_patch_request import ApiResourcesResourceIdScopesScopeIdPatchRequest
from py_logto.models.api_roles_get200_response_inner import ApiRolesGet200ResponseInner
from py_logto.models.api_roles_get200_response_inner_featured_applications_inner import ApiRolesGet200ResponseInnerFeaturedApplicationsInner
from py_logto.models.api_roles_get200_response_inner_featured_users_inner import ApiRolesGet200ResponseInnerFeaturedUsersInner
from py_logto.models.api_roles_id_applications_post_request import ApiRolesIdApplicationsPostRequest
from py_logto.models.api_roles_id_patch_request import ApiRolesIdPatchRequest
from py_logto.models.api_roles_id_scopes_get200_response_inner import ApiRolesIdScopesGet200ResponseInner
from py_logto.models.api_roles_id_scopes_post_request import ApiRolesIdScopesPostRequest
from py_logto.models.api_roles_id_users_post_request import ApiRolesIdUsersPostRequest
from py_logto.models.api_roles_post_request import ApiRolesPostRequest
from py_logto.models.api_sign_in_exp_get200_response import ApiSignInExpGet200Response
from py_logto.models.api_sign_in_exp_get200_response_color import ApiSignInExpGet200ResponseColor
from py_logto.models.api_sign_in_exp_get200_response_language_info import ApiSignInExpGet200ResponseLanguageInfo
from py_logto.models.api_sign_in_exp_get200_response_mfa import ApiSignInExpGet200ResponseMfa
from py_logto.models.api_sign_in_exp_get200_response_password_policy import ApiSignInExpGet200ResponsePasswordPolicy
from py_logto.models.api_sign_in_exp_get200_response_password_policy_character_types import ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes
from py_logto.models.api_sign_in_exp_get200_response_password_policy_length import ApiSignInExpGet200ResponsePasswordPolicyLength
from py_logto.models.api_sign_in_exp_get200_response_password_policy_rejects import ApiSignInExpGet200ResponsePasswordPolicyRejects
from py_logto.models.api_sign_in_exp_get200_response_sign_in import ApiSignInExpGet200ResponseSignIn
from py_logto.models.api_sign_in_exp_get200_response_sign_in_methods_inner import ApiSignInExpGet200ResponseSignInMethodsInner
from py_logto.models.api_sign_in_exp_get200_response_sign_up import ApiSignInExpGet200ResponseSignUp
from py_logto.models.api_sign_in_exp_patch200_response import ApiSignInExpPatch200Response
from py_logto.models.api_sign_in_exp_patch200_response_color import ApiSignInExpPatch200ResponseColor
from py_logto.models.api_sign_in_exp_patch200_response_language_info import ApiSignInExpPatch200ResponseLanguageInfo
from py_logto.models.api_sign_in_exp_patch200_response_mfa import ApiSignInExpPatch200ResponseMfa
from py_logto.models.api_sign_in_exp_patch200_response_password_policy import ApiSignInExpPatch200ResponsePasswordPolicy
from py_logto.models.api_sign_in_exp_patch200_response_sign_in import ApiSignInExpPatch200ResponseSignIn
from py_logto.models.api_sign_in_exp_patch200_response_sign_up import ApiSignInExpPatch200ResponseSignUp
from py_logto.models.api_sign_in_exp_patch_request import ApiSignInExpPatchRequest
from py_logto.models.api_sign_in_exp_patch_request_color import ApiSignInExpPatchRequestColor
from py_logto.models.api_sign_in_exp_patch_request_language_info import ApiSignInExpPatchRequestLanguageInfo
from py_logto.models.api_sign_in_exp_patch_request_sign_in import ApiSignInExpPatchRequestSignIn
from py_logto.models.api_sign_in_exp_patch_request_sign_up import ApiSignInExpPatchRequestSignUp
from py_logto.models.api_sign_in_exp_patch_request_terms_of_use_url import ApiSignInExpPatchRequestTermsOfUseUrl
from py_logto.models.api_sso_connector_providers_get200_response_inner import ApiSsoConnectorProvidersGet200ResponseInner
from py_logto.models.api_sso_connectors_get200_response_inner import ApiSsoConnectorsGet200ResponseInner
from py_logto.models.api_sso_connectors_get200_response_inner_branding import ApiSsoConnectorsGet200ResponseInnerBranding
from py_logto.models.api_sso_connectors_id_patch_request import ApiSsoConnectorsIdPatchRequest
from py_logto.models.api_sso_connectors_post200_response import ApiSsoConnectorsPost200Response
from py_logto.models.api_sso_connectors_post_request import ApiSsoConnectorsPostRequest
from py_logto.models.api_systems_application_get200_response import ApiSystemsApplicationGet200Response
from py_logto.models.api_systems_application_get200_response_protected_apps import ApiSystemsApplicationGet200ResponseProtectedApps
from py_logto.models.api_user_assets_post200_response import ApiUserAssetsPost200Response
from py_logto.models.api_user_assets_service_status_get200_response import ApiUserAssetsServiceStatusGet200Response
from py_logto.models.api_user_assets_service_status_get200_response_status import ApiUserAssetsServiceStatusGet200ResponseStatus
from py_logto.models.api_users_post_request import ApiUsersPostRequest
from py_logto.models.api_users_user_id_custom_data_patch_request import ApiUsersUserIdCustomDataPatchRequest
from py_logto.models.api_users_user_id_get200_response import ApiUsersUserIdGet200Response
from py_logto.models.api_users_user_id_get200_response_sso_identities_inner import ApiUsersUserIdGet200ResponseSsoIdentitiesInner
from py_logto.models.api_users_user_id_has_password_get200_response import ApiUsersUserIdHasPasswordGet200Response
from py_logto.models.api_users_user_id_identities_post_request import ApiUsersUserIdIdentitiesPostRequest
from py_logto.models.api_users_user_id_identities_target_put_request import ApiUsersUserIdIdentitiesTargetPutRequest
from py_logto.models.api_users_user_id_is_suspended_patch_request import ApiUsersUserIdIsSuspendedPatchRequest
from py_logto.models.api_users_user_id_mfa_verifications_get200_response_inner import ApiUsersUserIdMfaVerificationsGet200ResponseInner
from py_logto.models.api_users_user_id_mfa_verifications_post200_response import ApiUsersUserIdMfaVerificationsPost200Response
from py_logto.models.api_users_user_id_mfa_verifications_post200_response_one_of import ApiUsersUserIdMfaVerificationsPost200ResponseOneOf
from py_logto.models.api_users_user_id_mfa_verifications_post200_response_one_of1 import ApiUsersUserIdMfaVerificationsPost200ResponseOneOf1
from py_logto.models.api_users_user_id_mfa_verifications_post_request import ApiUsersUserIdMfaVerificationsPostRequest
from py_logto.models.api_users_user_id_mfa_verifications_post_request_type import ApiUsersUserIdMfaVerificationsPostRequestType
from py_logto.models.api_users_user_id_organizations_get200_response_inner import ApiUsersUserIdOrganizationsGet200ResponseInner
from py_logto.models.api_users_user_id_organizations_get200_response_inner_organization_roles_inner import ApiUsersUserIdOrganizationsGet200ResponseInnerOrganizationRolesInner
from py_logto.models.api_users_user_id_password_patch_request import ApiUsersUserIdPasswordPatchRequest
from py_logto.models.api_users_user_id_password_verify_post_request import ApiUsersUserIdPasswordVerifyPostRequest
from py_logto.models.api_users_user_id_patch200_response import ApiUsersUserIdPatch200Response
from py_logto.models.api_users_user_id_patch_request import ApiUsersUserIdPatchRequest
from py_logto.models.api_users_user_id_patch_request_avatar import ApiUsersUserIdPatchRequestAvatar
from py_logto.models.api_users_user_id_patch_request_name import ApiUsersUserIdPatchRequestName
from py_logto.models.api_users_user_id_patch_request_primary_email import ApiUsersUserIdPatchRequestPrimaryEmail
from py_logto.models.api_users_user_id_patch_request_primary_phone import ApiUsersUserIdPatchRequestPrimaryPhone
from py_logto.models.api_users_user_id_patch_request_username import ApiUsersUserIdPatchRequestUsername
from py_logto.models.api_users_user_id_profile_patch_request import ApiUsersUserIdProfilePatchRequest
from py_logto.models.api_users_user_id_profile_patch_request_profile import ApiUsersUserIdProfilePatchRequestProfile
from py_logto.models.api_verification_codes_verify_post_request import ApiVerificationCodesVerifyPostRequest
from py_logto.models.api_well_known_phrases_get200_response_value import ApiWellKnownPhrasesGet200ResponseValue
from py_logto.models.api_well_known_sign_in_exp_get200_response import ApiWellKnownSignInExpGet200Response
from py_logto.models.api_well_known_sign_in_exp_get200_response_forgot_password import ApiWellKnownSignInExpGet200ResponseForgotPassword
from py_logto.models.api_well_known_sign_in_exp_get200_response_social_connectors_inner import ApiWellKnownSignInExpGet200ResponseSocialConnectorsInner
from py_logto.models.api_well_known_sign_in_exp_get200_response_sso_connectors_inner import ApiWellKnownSignInExpGet200ResponseSsoConnectorsInner
from py_logto.models.translation import Translation
from py_logto.models.translation_object import TranslationObject



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_roles_inner_scopes_inner_resource import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource
from py_logto.models.api_resources_get200_response_inner import ApiResourcesGet200ResponseInner
from py_logto.models.api_resources_get200_response_inner_scopes_inner import ApiResourcesGet200ResponseInnerScopesInner
from py_logto.models.api_resources_id_is_default_patch_request import ApiResourcesIdIsDefaultPatchRequest
from py_logto.models.api_resources_id_patch_request import ApiResourcesIdPatchRequest
from py_logto.models.api_resources_post_request import ApiResourcesPostRequest
from py_logto.models.api_resources_resource_id_scopes_post_request import ApiResourcesResourceIdScopesPostRequest
from py_logto.models.api_resources_resource_id_scopes_scope_id_patch_request import ApiResourcesResourceIdScopesScopeIdPatchRequest

from py_logto.api_client import ApiClient, RequestSerialized
from py_logto.api_response import ApiResponse
from py_logto.rest import RESTResponseType


class ResourcesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_resources_get(
        self,
        include_scopes: Annotated[Optional[StrictStr], Field(description="If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ApiResourcesGet200ResponseInner]:
        """Get API resources

        Get API resources in the current tenant with pagination.

        :param include_scopes: If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.
        :type include_scopes: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_get_serialize(
            include_scopes=include_scopes,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_get_with_http_info(
        self,
        include_scopes: Annotated[Optional[StrictStr], Field(description="If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ApiResourcesGet200ResponseInner]]:
        """Get API resources

        Get API resources in the current tenant with pagination.

        :param include_scopes: If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.
        :type include_scopes: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_get_serialize(
            include_scopes=include_scopes,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_get_without_preload_content(
        self,
        include_scopes: Annotated[Optional[StrictStr], Field(description="If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get API resources

        Get API resources in the current tenant with pagination.

        :param include_scopes: If it's provided with a truthy value (`true`, `1`, `yes`), the scopes of each resource will be included in the response.
        :type include_scopes: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_get_serialize(
            include_scopes=include_scopes,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_get_serialize(
        self,
        include_scopes,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if include_scopes is not None:
            
            _query_params.append(('includeScopes', include_scopes))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/resources',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_id_delete(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete API resource

        Delete an API resource by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_id_delete_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete API resource

        Delete an API resource by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_id_delete_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete API resource

        Delete an API resource by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_id_delete_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/resources/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_id_get(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource:
        """Get API resource

        Get an API resource details by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_id_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource]:
        """Get API resource

        Get an API resource details by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_id_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get API resource

        Get an API resource details by ID.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/resources/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_id_is_default_patch(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource:
        """Set API resource as default

        Set an API resource as the default resource for the current tenant.  Each tenant can have only one default API resource. If an API resource is set as default, the previously set default API resource will be set as non-default. See [this section](https://docs.logto.io/docs/references/resources/#default-api) for more information.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_is_default_patch_request: (required)
        :type api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_is_default_patch_serialize(
            id=id,
            api_resources_id_is_default_patch_request=api_resources_id_is_default_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_id_is_default_patch_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource]:
        """Set API resource as default

        Set an API resource as the default resource for the current tenant.  Each tenant can have only one default API resource. If an API resource is set as default, the previously set default API resource will be set as non-default. See [this section](https://docs.logto.io/docs/references/resources/#default-api) for more information.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_is_default_patch_request: (required)
        :type api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_is_default_patch_serialize(
            id=id,
            api_resources_id_is_default_patch_request=api_resources_id_is_default_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_id_is_default_patch_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Set API resource as default

        Set an API resource as the default resource for the current tenant.  Each tenant can have only one default API resource. If an API resource is set as default, the previously set default API resource will be set as non-default. See [this section](https://docs.logto.io/docs/references/resources/#default-api) for more information.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_is_default_patch_request: (required)
        :type api_resources_id_is_default_patch_request: ApiResourcesIdIsDefaultPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_is_default_patch_serialize(
            id=id,
            api_resources_id_is_default_patch_request=api_resources_id_is_default_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_id_is_default_patch_serialize(
        self,
        id,
        api_resources_id_is_default_patch_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_resources_id_is_default_patch_request is not None:
            _body_params = api_resources_id_is_default_patch_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/resources/{id}/is-default',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_id_patch(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_patch_request: ApiResourcesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource:
        """Update API resource

        Update an API resource details by ID with the given data. This method performs a partial update.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_patch_request: (required)
        :type api_resources_id_patch_request: ApiResourcesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_patch_serialize(
            id=id,
            api_resources_id_patch_request=api_resources_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_id_patch_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_patch_request: ApiResourcesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource]:
        """Update API resource

        Update an API resource details by ID with the given data. This method performs a partial update.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_patch_request: (required)
        :type api_resources_id_patch_request: ApiResourcesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_patch_serialize(
            id=id,
            api_resources_id_patch_request=api_resources_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_id_patch_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_id_patch_request: ApiResourcesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update API resource

        Update an API resource details by ID with the given data. This method performs a partial update.

        :param id: The unique identifier of the resource. (required)
        :type id: str
        :param api_resources_id_patch_request: (required)
        :type api_resources_id_patch_request: ApiResourcesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_id_patch_serialize(
            id=id,
            api_resources_id_patch_request=api_resources_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_id_patch_serialize(
        self,
        id,
        api_resources_id_patch_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_resources_id_patch_request is not None:
            _body_params = api_resources_id_patch_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/resources/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_post(
        self,
        api_resources_post_request: ApiResourcesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Create an API resource

        Create an API resource in the current tenant.

        :param api_resources_post_request: (required)
        :type api_resources_post_request: ApiResourcesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_post_serialize(
            api_resources_post_request=api_resources_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_post_with_http_info(
        self,
        api_resources_post_request: ApiResourcesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Create an API resource

        Create an API resource in the current tenant.

        :param api_resources_post_request: (required)
        :type api_resources_post_request: ApiResourcesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_post_serialize(
            api_resources_post_request=api_resources_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_post_without_preload_content(
        self,
        api_resources_post_request: ApiResourcesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create an API resource

        Create an API resource in the current tenant.

        :param api_resources_post_request: (required)
        :type api_resources_post_request: ApiResourcesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_post_serialize(
            api_resources_post_request=api_resources_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_post_serialize(
        self,
        api_resources_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_resources_post_request is not None:
            _body_params = api_resources_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/resources',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_resource_id_scopes_get(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ApiResourcesGet200ResponseInnerScopesInner]:
        """Get API resource scopes

        Get scopes (permissions) defined for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_get_serialize(
            resource_id=resource_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInnerScopesInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_resource_id_scopes_get_with_http_info(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ApiResourcesGet200ResponseInnerScopesInner]]:
        """Get API resource scopes

        Get scopes (permissions) defined for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_get_serialize(
            resource_id=resource_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInnerScopesInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_resource_id_scopes_get_without_preload_content(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get API resource scopes

        Get scopes (permissions) defined for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_get_serialize(
            resource_id=resource_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiResourcesGet200ResponseInnerScopesInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_resource_id_scopes_get_serialize(
        self,
        resource_id,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resourceId'] = resource_id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/resources/{resourceId}/scopes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_resource_id_scopes_post(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Create API resource scope

        Create a new scope (permission) for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param api_resources_resource_id_scopes_post_request: (required)
        :type api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_post_serialize(
            resource_id=resource_id,
            api_resources_resource_id_scopes_post_request=api_resources_resource_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_resource_id_scopes_post_with_http_info(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Create API resource scope

        Create a new scope (permission) for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param api_resources_resource_id_scopes_post_request: (required)
        :type api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_post_serialize(
            resource_id=resource_id,
            api_resources_resource_id_scopes_post_request=api_resources_resource_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_resource_id_scopes_post_without_preload_content(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create API resource scope

        Create a new scope (permission) for an API resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param api_resources_resource_id_scopes_post_request: (required)
        :type api_resources_resource_id_scopes_post_request: ApiResourcesResourceIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_post_serialize(
            resource_id=resource_id,
            api_resources_resource_id_scopes_post_request=api_resources_resource_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_resource_id_scopes_post_serialize(
        self,
        resource_id,
        api_resources_resource_id_scopes_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resourceId'] = resource_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_resources_resource_id_scopes_post_request is not None:
            _body_params = api_resources_resource_id_scopes_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/resources/{resourceId}/scopes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_resource_id_scopes_scope_id_delete(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete API resource scope

        Delete an API resource scope (permission) from the given resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_delete_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_resource_id_scopes_scope_id_delete_with_http_info(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete API resource scope

        Delete an API resource scope (permission) from the given resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_delete_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_resource_id_scopes_scope_id_delete_without_preload_content(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete API resource scope

        Delete an API resource scope (permission) from the given resource.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_delete_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_resource_id_scopes_scope_id_delete_serialize(
        self,
        resource_id,
        scope_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resourceId'] = resource_id
        if scope_id is not None:
            _path_params['scopeId'] = scope_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/resources/{resourceId}/scopes/{scopeId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_resources_resource_id_scopes_scope_id_patch(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResourcesGet200ResponseInnerScopesInner:
        """Update API resource scope

        Update an API resource scope (permission) for the given resource. This method performs a partial update.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param api_resources_resource_id_scopes_scope_id_patch_request: (required)
        :type api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_patch_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            api_resources_resource_id_scopes_scope_id_patch_request=api_resources_resource_id_scopes_scope_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiResourcesGet200ResponseInnerScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_resources_resource_id_scopes_scope_id_patch_with_http_info(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiResourcesGet200ResponseInnerScopesInner]:
        """Update API resource scope

        Update an API resource scope (permission) for the given resource. This method performs a partial update.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param api_resources_resource_id_scopes_scope_id_patch_request: (required)
        :type api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_patch_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            api_resources_resource_id_scopes_scope_id_patch_request=api_resources_resource_id_scopes_scope_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiResourcesGet200ResponseInnerScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_resources_resource_id_scopes_scope_id_patch_without_preload_content(
        self,
        resource_id: Annotated[StrictStr, Field(description="The unique identifier of the resource.")],
        scope_id: Annotated[StrictStr, Field(description="The unique identifier of the scope.")],
        api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update API resource scope

        Update an API resource scope (permission) for the given resource. This method performs a partial update.

        :param resource_id: The unique identifier of the resource. (required)
        :type resource_id: str
        :param scope_id: The unique identifier of the scope. (required)
        :type scope_id: str
        :param api_resources_resource_id_scopes_scope_id_patch_request: (required)
        :type api_resources_resource_id_scopes_scope_id_patch_request: ApiResourcesResourceIdScopesScopeIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_resources_resource_id_scopes_scope_id_patch_serialize(
            resource_id=resource_id,
            scope_id=scope_id,
            api_resources_resource_id_scopes_scope_id_patch_request=api_resources_resource_id_scopes_scope_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiResourcesGet200ResponseInnerScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_resources_resource_id_scopes_scope_id_patch_serialize(
        self,
        resource_id,
        scope_id,
        api_resources_resource_id_scopes_scope_id_patch_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if resource_id is not None:
            _path_params['resourceId'] = resource_id
        if scope_id is not None:
            _path_params['scopeId'] = scope_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_resources_resource_id_scopes_scope_id_patch_request is not None:
            _body_params = api_resources_resource_id_scopes_scope_id_patch_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/resources/{resourceId}/scopes/{scopeId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.TestCase):
    """OrganizationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsApi()

    def tearDown(self) -> None:
        pass

    def test_api_organizations_get(self) -> None:
        """Test case for api_organizations_get

        Get organizations
        """
        pass

    def test_api_organizations_id_delete(self) -> None:
        """Test case for api_organizations_id_delete

        Delete organization
        """
        pass

    def test_api_organizations_id_get(self) -> None:
        """Test case for api_organizations_id_get

        Get organization
        """
        pass

    def test_api_organizations_id_patch(self) -> None:
        """Test case for api_organizations_id_patch

        Update organization
        """
        pass

    def test_api_organizations_id_users_get(self) -> None:
        """Test case for api_organizations_id_users_get

        Get organization user members
        """
        pass

    def test_api_organizations_id_users_post(self) -> None:
        """Test case for api_organizations_id_users_post

        Add user members to organization
        """
        pass

    def test_api_organizations_id_users_put(self) -> None:
        """Test case for api_organizations_id_users_put

        Replace organization user members
        """
        pass

    def test_api_organizations_id_users_roles_post(self) -> None:
        """Test case for api_organizations_id_users_roles_post

        Assign roles to organization user members
        """
        pass

    def test_api_organizations_id_users_user_id_delete(self) -> None:
        """Test case for api_organizations_id_users_user_id_delete

        Remove user member from organization
        """
        pass

    def test_api_organizations_id_users_user_id_roles_get(self) -> None:
        """Test case for api_organizations_id_users_user_id_roles_get

        Get roles for a user in an organization
        """
        pass

    def test_api_organizations_id_users_user_id_roles_post(self) -> None:
        """Test case for api_organizations_id_users_user_id_roles_post

        Assign roles to a user in an organization
        """
        pass

    def test_api_organizations_id_users_user_id_roles_put(self) -> None:
        """Test case for api_organizations_id_users_user_id_roles_put

        Update roles for a user in an organization
        """
        pass

    def test_api_organizations_id_users_user_id_roles_role_id_delete(self) -> None:
        """Test case for api_organizations_id_users_user_id_roles_role_id_delete

        Remove a role from a user in an organization
        """
        pass

    def test_api_organizations_post(self) -> None:
        """Test case for api_organizations_post

        Create an organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
